@@ -118,7 +118,7 @@ class LSTMQuant(QuantOperatorBase): # pragma: no cover
             kwargs.update(attribute_to_kwarg(attribute))
         kwargs["domain"] = ms_domain
 
-        quant_lstm_name = "" if node.name == "" else node.name + "_quant"
+        quant_lstm_name = node.name + "_quant"
         quant_lstm_node = onnx.helper.make_node("DynamicQuantizeLSTM", 
                                                 inputs, node.output, quant_lstm_name, **kwargs)
         self.quantizer.remove_nodes.append(node)
