@@ -27,9 +27,9 @@ from neural_compressor.experimental.common import Model
 from .transform_graph.rerange_quantized_concat import RerangeQuantizedConcat
 from .transform_graph.bias_correction import BiasCorrection
 from .quantize_graph.quantize_graph_for_intel_cpu import QuantizeGraphForIntel
-from .quantize_graph.quantize_graph_common import QuantizeGraphHelper
+from .quantize_graph_common import QuantizeGraphHelper
 
-from .graph_rewriter.graph_util import GraphAnalyzer
+from .graph_util import GraphAnalyzer
 from .graph_rewriter.generic.remove_training_nodes import RemoveTrainingNodesOptimizer
 from .graph_rewriter.generic.strip_unused_nodes import StripUnusedNodesOptimizer
 from .graph_rewriter.generic.fold_batch_norm import FoldBatchNormNodesOptimizer
@@ -56,7 +56,8 @@ class GraphConverterWithoutCalib:
     def __init__(self,
                  model,
                  data_loader=None,
-                 recover_config=None):
+                 recover_config=None,
+                 new_api=False):
         """Convert graph without calibration.
 
         :param model: input tensorflow model.
@@ -87,7 +88,7 @@ class GraphConverterWithoutCalib:
         self._check_tf_version()
         self._check_args()
         self._gen_tmp_filenames()
-
+        self.new_api = new_api          
         self._tmp_graph_def = copy.deepcopy(self.model.graph_def)
     # pylint: disable=no-member
     def _check_tf_version(self):
@@ -240,7 +241,8 @@ class GraphConverterWithoutCalib:
             self._tmp_graph_def,
             non_pad_ops,
             self._tmp_model.input_node_names,
-            self.op_wise_config).do_transformation()
+            self.op_wise_config,
+            self.new_api).do_transformation()
 
         self._tmp_graph_def = QuantizeGraphHelper().get_sorted_graph(
             self._tmp_graph_def,
@@ -254,7 +256,8 @@ class GraphConverterWithoutCalib:
             self.op_wise_config,
             self.int8_sequences,
             self.device,
-            False).do_transform()
+            False,
+            self.new_api).do_transform()
 
         self._tmp_graph_def.library.CopyFrom(self.model.graph_def.library)
         if debug:
@@ -293,7 +296,8 @@ class GraphConverterWithoutCalib:
     def _fuse_requantize_with_fused_quantized_node(self):
         self._tmp_graph_def = FuseConvRequantizeTransformer(
             self._tmp_graph_def,
-            self.device).do_transformation()
+            self.device,
+            self.new_api).do_transformation()
 
         self._tmp_graph_def = FuseMatMulRequantizeTransformer(
             self._tmp_graph_def).do_transformation()
