@@ -20,14 +20,15 @@ from tensorflow.python.framework import dtypes
 from neural_compressor.utils.utility import dump_elapsed_time
 
 from ..graph_base import GraphRewriterBase
-from ..graph_util import GraphAnalyzer
-from ..graph_util import GraphRewriterHelper as Helper
+from neural_compressor.adaptor.tf_utils.graph_util import GraphAnalyzer
+from neural_compressor.adaptor.tf_utils.graph_util import GraphRewriterHelper as Helper
+from neural_compressor.adaptor.tf_utils.util import version1_gt_version2
 
 
 class InjectDummyBiasAddOptimizer(GraphRewriterBase):
     def __init__(self, model, outputs):
         super().__init__(model)
-        self.outputs = outputs    
+        self.outputs = outputs
 
     @dump_elapsed_time("Pass InjectDummyBiasAddOptimizer")
     def do_transformation(self):
@@ -40,10 +41,10 @@ class InjectDummyBiasAddOptimizer(GraphRewriterBase):
             # only apply this pass for tensorflow release 2.9.1 and lower version for
             # old quantization API.
             # use conv+dummy_biasadd+relu because TF do not support conv+relu now. 
-            if tf.version.VERSION > '2.9.1': 
+            if version1_gt_version2(tf.version.VERSION, '2.9.1'):
                 continue
             if i[0] in self.outputs:
-                continue            
+                continue
             next_node_names = graph_info[i[0]].outputs
             if next_node_names and len(next_node_names) == 1 and \
                 graph_info[Helper.node_name_from_input(next_node_names[0])].node.op in valid_ops:
