@@ -17,7 +17,7 @@
 
 
 import logging
-from neural_compressor.adaptor.tf_utils.graph_rewriter.graph_util import GraphAnalyzer
+from neural_compressor.adaptor.tf_utils.graph_util import GraphAnalyzer
 from neural_compressor.utils.utility import dump_elapsed_time
 from .fuse_column_wise_mul import FuseColumnWiseMulOptimizer
 from .remove_training_nodes import RemoveTrainingNodesOptimizer
@@ -26,6 +26,7 @@ from .strip_unused_nodes import StripUnusedNodesOptimizer
 from .graph_cse_optimizer import GraphCseOptimizer
 from .fold_constant import GraphFoldConstantOptimizer
 from .fold_batch_norm import FoldBatchNormNodesOptimizer
+from .rename_batch_norm import RenameBatchNormOptimizer
 from .update_enter import UpdateEnterOptimizer
 from .convert_layout import ConvertLayoutOptimizer
 from .fuse_gelu import FuseGeluOptimizer
@@ -45,10 +46,10 @@ from .fuse_decomposed_bn import FuseDecomposedBNOptimizer
 
 
 class PreOptimization():
-    def __init__(self, model, optimization):
+    def __init__(self, model, optimization, new_api):
         self.model = model
         self.optimization = optimization
-
+        self.new_api = new_api
 
         self.analyzer = GraphAnalyzer()
         self.analyzer.graph = model.graph_def
@@ -66,7 +67,7 @@ class PreOptimization():
         return self._excluded_node_names
 
     @dump_elapsed_time("Pass Pre Optimization")
-    def get_optimized_model(self):
+    def get_optimized_model(self, itex_mode=False):
         """Executed the non-precision dependant graph optimization.
         The input graph will be optimized with following passes:
         1. Remove the training nodes like Identity Op.
@@ -96,10 +97,10 @@ class PreOptimization():
 
         self._tmp_graph_def = ConvertLayoutOptimizer(
             self.model.graph_def, output_node_names).do_transformation()
-            
+
         self._tmp_graph_def = GrapplerOptimizer(
             self._tmp_graph_def, input_output_names, self.optimization).do_transformation()
-         
+
         self._tmp_graph_def = SwitchOptimizer(self._tmp_graph_def).do_transformation()
 
         self._tmp_graph_def = RemoveTrainingNodesOptimizer(
@@ -107,7 +108,9 @@ class PreOptimization():
 
         self._tmp_graph_def = SplitSharedInputOptimizer(self._tmp_graph_def).do_transformation()
 
-        self._tmp_graph_def = GraphFoldConstantOptimizer(self._tmp_graph_def).do_transformation()
+        # disable fold constant for itex qdq mode
+        if not itex_mode:
+            self._tmp_graph_def = GraphFoldConstantOptimizer(self._tmp_graph_def).do_transformation()
 
         self._tmp_graph_def = FuseColumnWiseMulOptimizer(self._tmp_graph_def).do_transformation()
 
@@ -123,6 +126,9 @@ class PreOptimization():
         self._tmp_graph_def = FoldBatchNormNodesOptimizer(
             self._tmp_graph_def).do_transformation()
 
+        self._tmp_graph_def = RenameBatchNormOptimizer(
+            self._tmp_graph_def).do_transformation()
+
         #TODO we should handle all control ops elegantly not bypass it.
         self._tmp_graph_def, excluded_node_names = UpdateEnterOptimizer(
             self._tmp_graph_def).do_transformation()
@@ -141,14 +147,14 @@ class PreOptimization():
 
         self._tmp_graph_def = ExpandDimsOptimizer(
             self._tmp_graph_def).do_transformation()
-            
+
         self._tmp_graph_def = FetchWeightFromReshapeOptimizer(
-            self._tmp_graph_def).do_transformation()     
-        #TODO we need to remove below optimizer once the TF enabled the single
-        # matmul op quantization
-        self._tmp_graph_def = InjectDummyBiasAddOptimizer(
-            self._tmp_graph_def, output_node_names).do_transformation()
-            
+            self._tmp_graph_def).do_transformation()
+        if not self.new_api:
+            #TODO we need to remove below optimizer once the TF enabled the single
+            # matmul op quantization
+            self._tmp_graph_def = InjectDummyBiasAddOptimizer(
+                self._tmp_graph_def, output_node_names).do_transformation()
         self._tmp_graph_def = FuseBiasAddAndAddOptimizer(
             self._tmp_graph_def).do_transformation()
 
