@@ -15,14 +15,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import tensorflow as tf
 from tensorflow.core.framework import graph_pb2
 from tensorflow.core.framework import node_def_pb2
 from tensorflow.python.framework import dtypes
 from tensorflow.python.framework import tensor_util
 
-from .quantize_graph_common import QuantizeGraphHelper as helper
+from neural_compressor.adaptor.tf_utils.quantize_graph_common import QuantizeGraphHelper as helper
 from .quantize_graph_base import QuantizeNodeBase
-
+from neural_compressor.adaptor.tf_utils.util import version1_gte_version2
+import numpy as np
 
 class FuseNodeStartWithConv2d(QuantizeNodeBase):
 
@@ -31,6 +33,7 @@ class FuseNodeStartWithConv2d(QuantizeNodeBase):
         self.sorted_patterns = sorted(self.patterns,
                                       key=lambda i: len(i),
                                       reverse=True)
+
         self.fusion_mapping = {
             'Conv2DBiasAdd': self.apply_conv_biasadd_fusion,
             'Conv2DBiasAddAddNRelu': self.apply_conv_biasadd_addn_relu_fusion,
@@ -52,7 +55,7 @@ class FuseNodeStartWithConv2d(QuantizeNodeBase):
             'DepthwiseConv2dNativeBiasAddRelu6':
             self.apply_conv_biasadd_relu_fusion,
             'Conv2D': self.apply_conv_single_fusion,
-            'DepthwiseConv2dNative': self.apply_conv_single_fusion,
+            'DepthwiseConv2dNative': self.apply_conv_single_fusion
         }
 
     def apply_conv_single_fusion(self, match_node_name):
@@ -100,7 +103,7 @@ class FuseNodeStartWithConv2d(QuantizeNodeBase):
                                  node.attr["strides"])
                 helper.copy_attr(quantized_conv_node, "padding",
                                  node.attr["padding"])
-                if node.op != 'DepthwiseConv2dNative' and "padding_list" in node.attr:
+                if "padding_list" in node.attr:
                     helper.copy_attr(quantized_conv_node, "padding_list",
                                      node.attr["padding_list"])
                 helper.copy_attr(quantized_conv_node, "dilations",
@@ -171,7 +174,7 @@ class FuseNodeStartWithConv2d(QuantizeNodeBase):
                 if "alpha" in self.node_name_mapping[relu_node_name].node.attr:
                     helper.copy_attr(quantized_conv_node, "alpha",
                     self.node_name_mapping[relu_node_name].node.attr["alpha"])
-                if node.op != 'DepthwiseConv2dNative' and "padding_list" in node.attr:
+                if "padding_list" in node.attr:
                     helper.copy_attr(quantized_conv_node, "padding_list",
                     node.attr["padding_list"])
                 helper.copy_attr(quantized_conv_node, "dilations", node.attr["dilations"])
@@ -333,11 +336,15 @@ class FuseNodeStartWithConv2d(QuantizeNodeBase):
                     self._intel_cpu_add_dequantize_result_node(
                         quantize_down_name, match_node_name[3], dtype=dtypes.qint8)
                 else:
+                    dtype = dtypes.quint8
+                    if [i for i in self.node_name_mapping[relu_node_name].output \
+                        if 'FusedBatchNorm' in self.node_name_mapping[i].node.op and \
+                            i in self.op_wise_config_name_list]:
+                            dtype = dtypes.qint8
                     quantize_down_name = self._add_quantize_down_nodes(
-                        node, quantized_node_name, dtypes.quint8, is_relu6)
+                        node, quantized_node_name, dtype, is_relu6)
                     self._intel_cpu_add_dequantize_result_node(
-                        quantize_down_name, relu_node_name)
-
+                        quantize_down_name, relu_node_name, dtype)
             else:
                 new_node = node_def_pb2.NodeDef()
                 new_node.CopyFrom(node)
@@ -367,7 +374,7 @@ class FuseNodeStartWithConv2d(QuantizeNodeBase):
                                 fusion_name = 'Conv2D'
                                 matched_node_name = matched_node_name[:1]
                 self.fusion_mapping[fusion_name](matched_node_name)
-            else:
+            else: # pragma: no cover
                 self.logger.info("Unknown fusion pattern {}.".format(fusion_name))
                 if self.remove_redundant_quant_flag:
                     self.input_graph = self.remove_redundant_quantization(self.input_graph)
