@@ -168,7 +168,7 @@ class SigOptTuneStrategy(TuneStrategy):
 
         baseline_msg = '[Accuracy: {:.4f}'.format(self.baseline[0]) + \
             ''.join([', {}: {:.4f}'.format(x,y) for x,y in zip( \
-            self.multi_objective.representation, self.baseline[1]) if x != 'Accuracy']) + ']' \
+            self.objectives.representation, self.baseline[1]) if x != 'Accuracy']) + ']' \
             if self.baseline else 'n/a'
         logger.info("FP32 baseline is: {}".format(baseline_msg))
         self.experiment = self.create_exp(acc_target=self.get_acc_target(self.baseline[0]))
