@@ -20,8 +20,10 @@ from .quantization import Quantization
 from .pruning import Pruning
 from .benchmark import Benchmark
 from .graph_optimization import Graph_Optimization, GraphOptimization
+from .mixed_precision import MixedPrecision
 from .model_conversion import ModelConversion
 from .distillation import Distillation
+from .nas import NAS
 
 __all__ = ['Component', 'Quantization', 'Pruning', 'Benchmark', 'Graph_Optimization', \
-           'GraphOptimization', 'ModelConversion', 'Distillation']
+           'GraphOptimization', 'ModelConversion', 'Distillation', 'NAS', 'MixedPrecision']
