@@ -81,6 +81,7 @@ class Benchmark(object):
         self.framework = None
         self._model = None
         self._b_dataloader = None
+        self._b_func = None
         self._metric = None
         self._results = {}
         if isinstance(conf_fname_or_obj, BenchmarkConf):
@@ -168,7 +169,7 @@ class Benchmark(object):
                                    'approach': cfg.quantization.approach, \
                                    'random_seed': cfg.tuning.random_seed}
         framework = cfg.model.framework.lower()
-        if framework == 'tensorflow' or framework == 'tensorflow_itex':
+        if 'tensorflow' in framework:
             framework_specific_info.update({"inputs": cfg.model.inputs, \
                                             "outputs": cfg.model.outputs, \
                                             "recipes": cfg.model.recipes, \
@@ -183,11 +184,6 @@ class Benchmark(object):
         if framework == 'pytorch_ipex' or framework == 'pytorch' or framework == 'pytorch_fx':
             framework_specific_info.update({"workspace_path": cfg.tuning.workspace.path,
                                             "q_dataloader": None})
-        if framework == 'engine':
-            framework_specific_info.update(
-                 {"workspace_path": cfg.tuning.workspace.path, \
-                  "b_dataloader": self._b_dataloader, \
-                  'q_dtype': cfg.quantization.dtype})
 
         assert isinstance(self._model, BaseModel), 'need set neural_compressor Model for quantization....'
 
@@ -210,19 +206,14 @@ class Benchmark(object):
 
             b_dataloader_cfg = deep_get(cfg, 'evaluation.{}.dataloader'.format(mode))
             self._b_dataloader = create_dataloader(self.framework, b_dataloader_cfg)
-            b_func = create_eval_func(self.framework, \
-                                      self._b_dataloader, \
-                                      adaptor, \
-                                      metric, \
-                                      b_postprocess_cfg,
-                                      iteration=iteration)
-        else:
-            b_func = create_eval_func(self.framework, \
-                                      self._b_dataloader, \
-                                      adaptor, \
-                                      metric, \
-                                      b_postprocess_cfg,
-                                      iteration=iteration)
+            
+        if self._b_func is None:
+            self._b_func = create_eval_func(self.framework, \
+                                    self._b_dataloader, \
+                                    adaptor, \
+                                    metric, \
+                                    b_postprocess_cfg,
+                                    iteration=iteration)
 
         objectives = [i.lower() for i in cfg.tuning.multi_objectives.objective] if \
             deep_get(cfg, 'tuning.multi_objectives') else [cfg.tuning.objective]
@@ -231,7 +222,7 @@ class Benchmark(object):
                               cfg.tuning.accuracy_criterion,
                               is_measure=True)
 
-        val = self.objectives.evaluate(b_func, self._model)
+        val = self.objectives.evaluate(self._b_func, self._model)
         # measurer contain info not only performance(eg, memory, model_size)
         # also measurer have result list among steps
         acc, _ = val
@@ -300,6 +291,26 @@ class Benchmark(object):
         """
         self._b_dataloader = _generate_common_dataloader(dataloader, self.framework)
 
+    @property
+    def b_func(self):
+        """ not support get b_func """
+        assert False, 'Should not try to get the value of `b_func` attribute.'
+        return None
+
+    @b_func.setter
+    def b_func(self, user_b_func):
+        """Eval function for benchmark.
+
+        Args:
+            user_b_func: This function takes "model" as input parameter
+                         and executes entire training process with self
+                         contained training hyper-parameters. If train_func set,
+                         an evaluation process must be triggered and user should
+                         set eval_dataloader with metric configured or directly eval_func
+                         to make evaluation of the model executed.
+        """
+        self._b_func = user_b_func
+
     @property
     def model(self):
         return self._model
@@ -335,7 +346,7 @@ class Benchmark(object):
             set_backend(self.framework)  
 
         # (TODO) ugly to set these params, but tensorflow need
-        if self.framework == 'tensorflow':
+        if 'tensorflow' in self.framework:
             self._model.name = cfg.model.name
             self._model.output_tensor_names = cfg.model.outputs
             self._model.input_tensor_names = cfg.model.inputs
