@@ -40,19 +40,17 @@ class Model(object):
         backend = get_backend()
         framework = get_model_fwk_name(root)
 
-        if backend == 'engine':
-            model = MODELS[backend](root, **kwargs)
-        elif framework == 'tensorflow':
+        if framework == 'tensorflow':
             if 'modelType' in kwargs:
                 model_type = kwargs['modelType']
             else:
                 model_type = get_model_type(root)
             model = MODELS['tensorflow'](model_type, root, **kwargs)
         elif framework == 'pytorch':
-            assert backend != 'NA', 'please set pytorch backend'
+            if backend == 'NA':
+                backend = 'pytorch'
             model = MODELS[backend](root, **kwargs)
         else:
             model = MODELS[framework](root, **kwargs)
         return model
-    
 
