@@ -19,10 +19,10 @@ from .tensorflow_dataloader import TensorflowDataLoader
 from .mxnet_dataloader import MXNetDataLoader
 from .pytorch_dataloader import PyTorchDataLoader
 from .onnxrt_dataloader import ONNXRTDataLoader
-from .engine_dataloader import EngineDataLoader
 from .default_dataloader import DefaultDataLoader
 
 DATALOADERS = {"tensorflow": TensorflowDataLoader,
+               "inteltensorflow": TensorflowDataLoader,
                "tensorflow_itex": TensorflowDataLoader,
                "mxnet": MXNetDataLoader,
                "pytorch": PyTorchDataLoader,
@@ -32,5 +32,5 @@ DATALOADERS = {"tensorflow": TensorflowDataLoader,
                "onnxrt_integerops": ONNXRTDataLoader,
                "onnxrt_qdq": ONNXRTDataLoader,
                "onnxrt_qoperator": ONNXRTDataLoader,
-               "engine": EngineDataLoader}
+               }
 
