@@ -88,13 +88,9 @@ class PytorchMxnetWrapFunction():
             sample = self.transform(sample)
         return sample
 
-@singleton
-class EngineDatasets(object):
-    def __init__(self):
-        self.datasets = {}
-        self.datasets.update(ENGINE_DATASETS)
 
 framework_datasets = {"tensorflow": TensorflowDatasets,
+                      "inteltensorflow": TensorflowDatasets,
                       "tensorflow_itex": TensorflowDatasets,
                       "mxnet": MXNetDatasets,
                       "pytorch": PyTorchDatasets,
@@ -104,7 +100,7 @@ framework_datasets = {"tensorflow": TensorflowDatasets,
                       "onnxrt_qlinearops": ONNXRTQLDatasets,
                       "onnxrt_qoperator": ONNXRTQLDatasets,
                       "onnxrt_integerops": ONNXRTITDatasets,
-                      "engine": EngineDatasets}
+                      }
 
 """The datasets supported by neural_compressor, it's model specific and can be configured by yaml file.
 
@@ -119,11 +115,10 @@ framework_datasets = {"tensorflow": TensorflowDatasets,
 
 class DATASETS(object):
     def __init__(self, framework):
-        assert framework in ["tensorflow", "tensorflow_itex", "onnxrt_qdq",
-                             "mxnet", "onnxrt_qlinearops", "onnxrt_integerops",
-                             "pytorch", "pytorch_ipex", "pytorch_fx", "engine",
-                             "onnxrt_qoperator"], \
-                             "framework support tensorflow pytorch mxnet onnxrt engine"
+        assert framework in ["inteltensorflow", "tensorflow", "tensorflow_itex", \
+                             "mxnet", "onnxrt_qdq", "onnxrt_qlinearops", "onnxrt_integerops", \
+                             "pytorch", "pytorch_ipex", "pytorch_fx", "onnxrt_qoperator"], \
+                             "framework support tensorflow pytorch mxnet onnxrt"
         self.datasets = framework_datasets[framework]().datasets
 
     def __getitem__(self, dataset_type):
@@ -133,6 +128,7 @@ class DATASETS(object):
 
 # user/model specific datasets will be registered here
 TENSORFLOW_DATASETS = {}
+INTELTENSORFLOW_DATASETS = {}
 TENSORFLOWITEX_DATASETS = {}
 MXNET_DATASETS = {}
 PYTORCH_DATASETS = {}
@@ -140,9 +136,9 @@ PYTORCHIPEX_DATASETS = {}
 PYTORCHFX_DATASETS = {}
 ONNXRTQL_DATASETS = {}
 ONNXRTIT_DATASETS = {}
-ENGINE_DATASETS = {}
 
 registry_datasets = {"tensorflow": TENSORFLOW_DATASETS,
+                     "inteltensorflow": INTELTENSORFLOW_DATASETS,
                      "tensorflow_itex": TENSORFLOWITEX_DATASETS,
                      "mxnet": MXNET_DATASETS,
                      "pytorch": PYTORCH_DATASETS,
@@ -152,7 +148,7 @@ registry_datasets = {"tensorflow": TENSORFLOW_DATASETS,
                      "onnxrt_qdq": ONNXRTQL_DATASETS,
                      "onnxrt_qoperator": ONNXRTQL_DATASETS,
                      "onnxrt_qlinearops": ONNXRTQL_DATASETS,
-                     "engine": ENGINE_DATASETS}
+                    }
 
 
 def dataset_registry(dataset_type, framework, dataset_format=''):
@@ -172,6 +168,7 @@ def dataset_registry(dataset_type, framework, dataset_format=''):
         for single_framework in [fwk.strip() for fwk in framework.split(',')]:
             assert single_framework in [
                 "tensorflow",
+                "inteltensorflow",
                 "tensorflow_itex",
                 "mxnet",
                 "pytorch",
@@ -181,8 +178,7 @@ def dataset_registry(dataset_type, framework, dataset_format=''):
                 "onnxrt_integerops",
                 "onnxrt_qdq",
                 "onnxrt_qoperator",
-                "engine"
-            ], "The framework support tensorflow mxnet pytorch onnxrt engine"
+            ], "The framework support tensorflow mxnet pytorch onnxrt"
             dataset_name = dataset_type + dataset_format
             if dataset_name in registry_datasets[single_framework].keys():
                 raise ValueError('Cannot have two datasets with the same name')
@@ -407,7 +403,8 @@ class MXNetCIFAR10(CIFAR10):
             image, label = self.transform((image, label))
         return (image, label)
 
-@dataset_registry(dataset_type="CIFAR10", framework="tensorflow", dataset_format='')
+@dataset_registry(dataset_type="CIFAR10", framework="tensorflow, inteltensorflow, \
+                  tensorflow_itex", dataset_format='')
 class TensorflowCIFAR10(CIFAR10):
     def __getitem__(self, index): # pragma: no cover
         image, label = self.data[index], self.targets[index]
@@ -457,7 +454,8 @@ class MXNetCIFAR100(CIFAR100):
             image, label = self.transform((image, label))
         return (image, label)
 
-@dataset_registry(dataset_type="CIFAR100", framework="tensorflow", dataset_format='')
+@dataset_registry(dataset_type="CIFAR100", framework="tensorflow, inteltensorflow, \
+                  tensorflow_itex", dataset_format='')
 class TensorflowCIFAR100(CIFAR100):
     def __getitem__(self, index): # pragma: no cover
         image, label = self.data[index], self.targets[index]
@@ -565,7 +563,8 @@ class MXNetMNIST(MNIST):
             image, label = self.transform((image, label))
         return (image, label)
 
-@dataset_registry(dataset_type="MNIST", framework="tensorflow", dataset_format='')
+@dataset_registry(dataset_type="MNIST", framework="tensorflow, inteltensorflow, \
+                  tensorflow_itex", dataset_format='')
 class TensorflowMNIST(MNIST):
     def __getitem__(self, index):
         image, label = self.data[index], int(self.targets[index])
@@ -629,7 +628,8 @@ class MXNetFashionMNIST(FashionMNIST):
             image, label = self.transform((image, label))
         return (image, label)
 
-@dataset_registry(dataset_type="FashionMNIST", framework="tensorflow", dataset_format='')
+@dataset_registry(dataset_type="FashionMNIST", framework="tensorflow, inteltensorflow, \
+                  tensorflow_itex", dataset_format='')
 class TensorflowFashionMNIST(FashionMNIST):
     def __getitem__(self, index):
         image, label = self.data[index], int(self.targets[index])
@@ -702,7 +702,8 @@ class MXNetImageFolder(ImageFolder):
             image, label = self.transform((image, label))
         return (image, label)
 
-@dataset_registry(dataset_type="ImageFolder", framework="tensorflow", dataset_format='')
+@dataset_registry(dataset_type="ImageFolder", framework="tensorflow, inteltensorflow, \
+                  tensorflow_itex", dataset_format='')
 class TensorflowImageFolder(ImageFolder):
     def __getitem__(self, index):
         sample = self.image_list[index]
@@ -720,7 +721,8 @@ class TensorflowImageFolder(ImageFolder):
                 image = image.numpy()
             return (image, label)
 
-@dataset_registry(dataset_type="TFRecordDataset", framework="tensorflow", dataset_format='')
+@dataset_registry(dataset_type="TFRecordDataset", framework="tensorflow, inteltensorflow, \
+                  tensorflow_itex", dataset_format='')
 class TensorflowTFRecordDataset(IterableDataset):
     """Configuration for TensorflowTFRecordDataset
 
@@ -744,7 +746,8 @@ class TensorflowTFRecordDataset(IterableDataset):
         ds = ds.prefetch(buffer_size=tf.data.experimental.AUTOTUNE)  # this number can be tuned
         return ds
 
-@dataset_registry(dataset_type="ImageRecord", framework="tensorflow", dataset_format='')
+@dataset_registry(dataset_type="ImageRecord", framework="tensorflow, inteltensorflow, \
+                  tensorflow_itex", dataset_format='')
 class TensorflowImageRecord(IterableDataset):
     """Configuration for ImageNet database in tf record format
 
@@ -785,7 +788,8 @@ class TensorflowImageRecord(IterableDataset):
         ds = ds.prefetch(buffer_size=tf.data.experimental.AUTOTUNE)  # this number can be tuned
         return ds
 
-@dataset_registry(dataset_type="VOCRecord", framework="tensorflow", dataset_format='')
+@dataset_registry(dataset_type="VOCRecord", framework="tensorflow, inteltensorflow, \
+                  tensorflow_itex", dataset_format='')
 class TensorflowVOCRecord(IterableDataset):
     """Configuration for PASCAL VOC 2012 database in tf record format
 
