@@ -169,23 +169,9 @@ class ONNXRTITTransforms(Transforms):
         general.update(ONNXRT_IT_TRANSFORMS["general"])
         return general
 
-class EngineTransforms(Transforms):
-    def _get_preprocess(self):
-        preprocess = {}
-        preprocess.update(ENGINE_TRANSFORMS["preprocess"])
-        return preprocess
-
-    def _get_postprocess(self):
-        postprocess = {}
-        postprocess.update(ENGINE_TRANSFORMS["postprocess"])
-        return postprocess
-
-    def _get_general(self):
-        general = {}
-        general.update(ENGINE_TRANSFORMS["general"])
-        return general
 
 framework_transforms = {"tensorflow": TensorflowTransforms,
+                        "inteltensorflow": TensorflowTransforms,
                         "tensorflow_itex": TensorflowTransforms,
                         "mxnet": MXNetTransforms,
                         "pytorch": PyTorchTransforms,
@@ -194,19 +180,22 @@ framework_transforms = {"tensorflow": TensorflowTransforms,
                         "onnxrt_qlinearops": ONNXRTQLTransforms,
                         "onnxrt_integerops": ONNXRTITTransforms,
                         "onnxrt_qoperator": ONNXRTQLTransforms,
-                        "onnxrt_qdq": ONNXRTQLTransforms,
-                        "engine": EngineTransforms}
+                        "onnxrt_qdq": ONNXRTQLTransforms}
 
 # transform registry will register transforms into these dicts
 TENSORFLOW_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
+TENSORFLOW_ITEX_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
+INTELTENSORFLOW_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
+TENSORFLOW_QDQ_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
+TENSORFLOW_ITEX_QDQ_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
 MXNET_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
 PYTORCH_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
 ONNXRT_QL_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
 ONNXRT_IT_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
-ENGINE_TRANSFORMS = {"preprocess": {}, "postprocess": {}, "general": {}}
 
 registry_transforms = {"tensorflow": TENSORFLOW_TRANSFORMS,
-                       "tensorflow_itex": TENSORFLOW_TRANSFORMS,
+                       "inteltensorflow": INTELTENSORFLOW_TRANSFORMS,
+                       "tensorflow_itex": TENSORFLOW_ITEX_TRANSFORMS,
                        "mxnet": MXNET_TRANSFORMS,
                        "pytorch": PYTORCH_TRANSFORMS,
                        "pytorch_ipex": PYTORCH_TRANSFORMS,
@@ -215,14 +204,15 @@ registry_transforms = {"tensorflow": TENSORFLOW_TRANSFORMS,
                        "onnxrt_qdq": ONNXRT_QL_TRANSFORMS,
                        "onnxrt_qoperator": ONNXRT_QL_TRANSFORMS,
                        "onnxrt_integerops": ONNXRT_IT_TRANSFORMS,
-                       "engine": ENGINE_TRANSFORMS}
+                       }
 
 class TRANSFORMS(object):
     def __init__(self, framework, process):
-        assert framework in ("tensorflow", "tensorflow_itex", "engine", "onnxrt_qoperator",
+        assert framework in ("tensorflow", "inteltensorflow", "tensorflow_itex", \
+                             "onnxrt_qoperator", \
                              "pytorch", "pytorch_ipex", "pytorch_fx", "onnxrt_qdq",
                              "onnxrt_qlinearops", "onnxrt_integerops", "mxnet"), \
-                             "framework support tensorflow pytorch mxnet onnxrt engine"
+                             "framework support tensorflow pytorch mxnet onnxrt"
         assert process in ("preprocess", "postprocess",
                            "general"), "process support preprocess postprocess, general"
         self.transforms = framework_transforms[framework](process).transforms
@@ -257,6 +247,7 @@ def transform_registry(transform_type, process, framework):
         for single_framework in [fwk.strip() for fwk in framework.split(',')]:
             assert single_framework in [
                 "tensorflow",
+                "inteltensorflow",
                 "tensorflow_itex",
                 "mxnet",
                 "pytorch",
@@ -266,8 +257,7 @@ def transform_registry(transform_type, process, framework):
                 "onnxrt_qdq",
                 "onnxrt_integerops",
                 "onnxrt_qoperator",
-                "engine"
-            ], "The framework support tensorflow mxnet pytorch onnxrt engine"
+            ], "The framework support tensorflow mxnet pytorch onnxrt"
             if transform_type in registry_transforms[single_framework][process].keys():
                 raise ValueError('Cannot have two transforms with the same name')
             registry_transforms[single_framework][process][transform_type] = cls
@@ -348,7 +338,8 @@ def get_torchvision_map(interpolation):
         return interpolation
 
 @transform_registry(transform_type="Compose", process="general", \
-                 framework="onnxrt_qlinearops, onnxrt_integerops, tensorflow, engine")
+                    framework="onnxrt_qlinearops, onnxrt_integerops, tensorflow, \
+                    inteltensorflow, tensorflow_itex")
 class ComposeTransform(BaseTransform):
     """Composes several transforms together.
 
@@ -445,7 +436,7 @@ class ONNXRTCropToBoundingBox(CropToBoundingBox):
         return (image, label)
 
 @transform_registry(transform_type="CropToBoundingBox", process="preprocess", \
-                framework="tensorflow")
+                    framework="tensorflow, inteltensorflow, tensorflow_itex")
 class TensorflowCropToBoundingBox(CropToBoundingBox):
     """Crops an image to a specified bounding box.
 
@@ -524,7 +515,7 @@ class ResizeWithRatio(BaseTransform):
         return image, (bbox, str_label, int_label, image_id)
 
 @transform_registry(transform_type="ResizeWithRatio", process="preprocess", \
-                framework="tensorflow")
+                    framework="tensorflow, inteltensorflow, tensorflow_itex")
 class TensorflowResizeWithRatio(BaseTransform):
     """Resize image with aspect ratio and pad it to max shape(optional).
        If the image is padded, the label will be processed at the same time.
@@ -605,7 +596,8 @@ class Transpose(BaseTransform):
         image = np.transpose(image, axes=self.perm)
         return (image, label)
 
-@transform_registry(transform_type="Transpose", process="preprocess", framework="tensorflow")
+@transform_registry(transform_type="Transpose", process="preprocess", \
+                    framework="tensorflow, tensorflow_itex, inteltensorflow")
 class TensorflowTranspose(Transpose):
     """Transpose image according to perm.
 
@@ -675,7 +667,7 @@ class RandomVerticalFlip(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type="RandomVerticalFlip", process="preprocess", \
-        framework="tensorflow")
+                    framework="tensorflow, tensorflow_itex, inteltensorflow")
 class TensorflowRandomVerticalFlip(BaseTransform):
     """Vertically flip the given image randomly.
 
@@ -708,7 +700,7 @@ class RandomHorizontalFlip(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type="RandomHorizontalFlip", process="preprocess", \
-        framework="tensorflow")
+                    framework="tensorflow, tensorflow_itex, inteltensorflow")
 class TensorflowRandomHorizontalFlip(BaseTransform):
     """Horizontally flip the given image randomly.
 
@@ -726,7 +718,8 @@ class TensorflowRandomHorizontalFlip(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type="ToArray", process="preprocess", \
-        framework="onnxrt_qlinearops, onnxrt_integerops, tensorflow, pytorch, mxnet")
+                    framework="onnxrt_qlinearops, onnxrt_integerops, tensorflow, \
+                    tensorflow_itex, inteltensorflow, pytorch, mxnet")
 class ToArray(BaseTransform):
     """Convert PIL Image or NDArray to numpy array.
 
@@ -751,8 +744,8 @@ np_dtype_map = {'int8': np.int8, 'uint8': np.uint8, 'complex64': np.complex64,
            'float16': np.float16, 'float64': np.float64, 'bool': np.bool,
            'string': np.str, 'complex128': np.complex128, 'int16': np.int16}
 
-@transform_registry(transform_type="Cast",
-                    process="general", framework="tensorflow")
+@transform_registry(transform_type="Cast", process="general", \
+                    framework="tensorflow, inteltensorflow, tensorflow_itex")
 class CastTFTransform(BaseTransform):
     """Convert image to given dtype.
 
@@ -826,8 +819,8 @@ class CastPyTorchTransform(BaseTransform):
         image = image.type(self.dtype)
         return (image, label)
 
-@transform_registry(transform_type="CenterCrop",
-                    process="preprocess", framework="tensorflow")
+@transform_registry(transform_type="CenterCrop", process="preprocess", \
+                    framework="tensorflow, inteltensorflow, tensorflow_itex")
 class CenterCropTFTransform(BaseTransform):
     """Crops the given image at the center to the given size.
 
@@ -867,7 +860,7 @@ class CenterCropTFTransform(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type="PaddedCenterCrop", process="preprocess", \
-                framework="tensorflow")
+                    framework="tensorflow, inteltensorflow, tensorflow_itex")
 class PaddedCenterCropTransform(BaseTransform):
     def __init__(self, size, crop_padding=0):
         if isinstance(size, int):
@@ -893,8 +886,8 @@ class PaddedCenterCropTransform(BaseTransform):
         image = image[y0:y0 + padded_center_crop_size, x0:x0 + padded_center_crop_size, :]
         return (image, label)
 
-@transform_registry(transform_type="Resize",
-                    process="preprocess", framework="tensorflow")
+@transform_registry(transform_type="Resize", process="preprocess", \
+                    framework="tensorflow, inteltensorflow, tensorflow_itex")
 class ResizeTFTransform(BaseTransform):
     """Resize the input image to the given size.
 
@@ -955,8 +948,8 @@ class ResizePytorchTransform(BaseTransform):
                                         interpolation=self.interpolation)
         return (transformer(image), label)
 
-@transform_registry(transform_type="RandomCrop",
-                    process="preprocess", framework="tensorflow")
+@transform_registry(transform_type="RandomCrop", process="preprocess", \
+                    framework="tensorflow, inteltensorflow, tensorflow_itex")
 class RandomCropTFTransform(BaseTransform):
     """Crop the image at a random location to the given size.
 
@@ -1089,8 +1082,8 @@ class RandomResizedCropMXNetTransform(BaseTransform):
         return (transformer(image), label)
 
 
-@transform_registry(transform_type="RandomResizedCrop",
-                    process="preprocess", framework="tensorflow")
+@transform_registry(transform_type="RandomResizedCrop", process="preprocess", \
+                    framework="tensorflow, inteltensorflow, tensorflow_itex")
 class RandomResizedCropTFTransform(BaseTransform):
     """Crop the given image to random size and aspect ratio.
 
@@ -1189,8 +1182,8 @@ class RandomResizedCropTFTransform(BaseTransform):
             image, label = transform(sample)
         return (image, label)
 
-@transform_registry(transform_type="Normalize", process="preprocess",
-                        framework="tensorflow")
+@transform_registry(transform_type="Normalize", process="preprocess", \
+                    framework="tensorflow, inteltensorflow, tensorflow_itex")
 class NormalizeTFTransform(BaseTransform):
     """Normalize a image with mean and standard deviation.
 
@@ -1233,7 +1226,7 @@ class NormalizeTFTransform(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type='KerasRescale', process="preprocess", \
-                framework='tensorflow')
+                    framework='tensorflow, inteltensorflow, tensorflow_itex')
 class RescaleKerasPretrainTransform(BaseTransform):
     """Scale the values of image to [0,1].
 
@@ -1251,7 +1244,7 @@ class RescaleKerasPretrainTransform(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type='Rescale', process="preprocess", \
-                framework='tensorflow')
+                    framework='tensorflow, inteltensorflow, tensorflow_itex')
 class RescaleTFTransform(BaseTransform):
     """Scale the values of image to [0,1].
 
@@ -1283,7 +1276,8 @@ class RescaleTransform(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type='AlignImageChannel', process="preprocess", \
-    framework='tensorflow, onnxrt_qlinearops, onnxrt_integerops, mxnet')
+                    framework='tensorflow, inteltensorflow, tensorflow_itex, \
+                               onnxrt_qlinearops, onnxrt_integerops, mxnet')
 class AlignImageChannelTransform(BaseTransform):
     """ Align image channel, now just support [H,W]->[H,W,dim], [H,W,4]->[H,W,3] and
         [H,W,3]->[H,W].
@@ -1426,7 +1420,7 @@ class ResizeTransform(BaseTransform):
         return (image, label)
 
 @transform_registry(transform_type="CropResize", process="preprocess", \
-                framework="tensorflow")
+                    framework="tensorflow, inteltensorflow, tensorflow_itex")
 class CropResizeTFTransform(BaseTransform):
     """Crop the input image with given location and resize it.
 
@@ -2129,7 +2123,7 @@ def convert_examples_to_features(examples, tokenizer, max_seq_length,
             unique_id += 1
 
 @transform_registry(transform_type="Collect", \
-                process="postprocess", framework="engine")
+                process="postprocess", framework="tensorflow")
 class CollectTransform(BaseTransform):
     def __init__(self, length=10833):
         self.length = length
@@ -2153,8 +2147,8 @@ class CollectTransform(BaseTransform):
             self.all_sample = ([self.unique_id, self.start_logits, self.end_logits], label)
         return self.all_sample
 
-@transform_registry(transform_type="SquadV1", \
-                process="postprocess", framework="tensorflow")
+@transform_registry(transform_type="SquadV1", process="postprocess", \
+                    framework="tensorflow, inteltensorflow, tensorflow_itex")
 class TFSquadV1PostTransform(BaseTransform):
     """Postprocess the predictions of bert on SQuAD.
 
@@ -2249,6 +2243,10 @@ class TFSquadV1PostTransform(BaseTransform):
             null_start_logit = 0  # the start logit at the slice with min null score
             null_end_logit = 0  # the end logit at the slice with min null score
             for (feature_index, feature) in enumerate(features):
+                # skip the case that is not predicted
+                if not feature.unique_id in unique_id_to_result:
+                    all_predictions[example.qas_id] = "*#skip this example#*"
+                    continue
                 result = unique_id_to_result[feature.unique_id]
                 start_indexes = _get_best_indexes(result.start_logits, self.n_best_size)
                 end_indexes = _get_best_indexes(result.end_logits, self.n_best_size)
@@ -2358,25 +2356,42 @@ class TFSquadV1PostTransform(BaseTransform):
     def __call__(self, sample):
         return self.get_postprocess_result(sample)   
 
-@transform_registry(transform_type="SquadV1", \
-                process="postprocess", framework="engine")
-class EngineSquadV1PostTransform(TFSquadV1PostTransform):
+
+@transform_registry(transform_type="ModelZooCollect", \
+                process="postprocess", framework="tensorflow")
+class TFModelZooCollectTransform(CollectTransform):
+    def __call__(self, sample):
+        all_results, label = sample
+        all_results = zip(all_results[0], all_results[1])
+        for start_logits, end_logits in all_results:
+            if len(self.unique_id) < self.length:
+                self.unique_id.append(self.idx)
+                self.start_logits.append(start_logits)
+                self.end_logits.append(end_logits)
+                self.idx += 1
+        if len(self.unique_id) == self.length:
+            self.all_sample = ([self.unique_id, self.start_logits, self.end_logits], label)
+        return self.all_sample
+
+@transform_registry(transform_type="SquadV1ModelZoo", \
+                    process="postprocess", framework="tensorflow, inteltensorflow, \
+                              tensorflow_itex")
+class TFSquadV1ModelZooPostTransform(TFSquadV1PostTransform):
     """ Postprocess the predictions of bert on SQuADV1.1
         See class TFSquadV1PostTransform for more details """
-
     def __init__(self, label_file, vocab_file, n_best_size=20, max_seq_length=384, \
         max_query_length=64, max_answer_length=30, do_lower_case=True, doc_stride=128):
         super().__init__(label_file, vocab_file, n_best_size, max_seq_length, \
                 max_query_length, max_answer_length, do_lower_case, doc_stride)
         self.length = len(self.eval_features)
-        self.collect_data = CollectTransform(length=self.length)
+        self.collect_data = TFModelZooCollectTransform(length=self.length)
 
     def __call__(self, sample):
         sample = self.collect_data(sample)
         return self.get_postprocess_result(sample)
 
-@transform_registry(transform_type="ParseDecodeVoc", \
-                    process="preprocess", framework="tensorflow")
+@transform_registry(transform_type="ParseDecodeVoc", process="preprocess", \
+                    framework="tensorflow, inteltensorflow, tensorflow_itex")
 class ParseDecodeVocTransform(BaseTransform):
     """Parse features in Example proto.
 
