@@ -68,13 +68,8 @@ class ONNXRTITMetrics(object):
         self.metrics = {}
         self.metrics.update(ONNXRT_IT_METRICS)
 
-@singleton
-class EngineMetrics(object):
-    def __init__(self):
-        self.metrics = {}
-        self.metrics.update(ENGINE_METRICS)
-
 framework_metrics = {"tensorflow": TensorflowMetrics,
+                     "inteltensorflow": TensorflowMetrics,
                      "tensorflow_itex": TensorflowMetrics,
                      "mxnet": MXNetMetrics,
                      "pytorch": PyTorchMetrics,
@@ -83,19 +78,20 @@ framework_metrics = {"tensorflow": TensorflowMetrics,
                      "onnxrt_qlinearops": ONNXRTQLMetrics,
                      "onnxrt_integerops": ONNXRTITMetrics,
                      "onnxrt_qdq": ONNXRTQLMetrics,
-                     "onnxrt_qoperator": ONNXRTQLMetrics,
-                     "engine": EngineMetrics}
+                     "onnxrt_qoperator": ONNXRTQLMetrics}
 
 # user/model specific metrics will be registered here
 TENSORFLOW_METRICS = {}
+INTELTENSORFLOW_METRICS = {}
+TENSORFLOW_ITEX_METRICS = {}
 MXNET_METRICS = {}
 PYTORCH_METRICS = {}
 ONNXRT_QL_METRICS = {}
 ONNXRT_IT_METRICS = {}
-ENGINE_METRICS = {}
 
 registry_metrics = {"tensorflow": TENSORFLOW_METRICS,
-                    "tensorflow_itex": TENSORFLOW_METRICS,
+                    "inteltensorflow": INTELTENSORFLOW_METRICS,
+                    "tensorflow_itex": TENSORFLOW_ITEX_METRICS,
                     "mxnet": MXNET_METRICS,
                     "pytorch": PYTORCH_METRICS,
                     "pytorch_ipex": PYTORCH_METRICS,
@@ -104,16 +100,16 @@ registry_metrics = {"tensorflow": TENSORFLOW_METRICS,
                     "onnxrt_qdq": ONNXRT_QL_METRICS,
                     "onnxrt_integerops": ONNXRT_IT_METRICS,
                     "onnxrt_qoperator": ONNXRT_QL_METRICS,
-                    "engine": ENGINE_METRICS,}
+                    }
 
 
 class METRICS(object):
     def __init__(self, framework):
-        assert framework in ("tensorflow", "tensorflow_itex", "engine",
+        assert framework in ("tensorflow", "inteltensorflow", "tensorflow_itex",
                             "pytorch", "pytorch_ipex", "pytorch_fx", "onnxrt_qdq",
-                             "onnxrt_qlinearops", "onnxrt_integerops", "mxnet", 
+                             "onnxrt_qlinearops", "onnxrt_integerops", "mxnet",
                              "onnxrt_qoperator"), \
-                             "framework support tensorflow pytorch mxnet onnxrt engine"
+                             "framework support tensorflow pytorch mxnet onnxrt"
         self.metrics = framework_metrics[framework]().metrics
 
     def __getitem__(self, metric_type):
@@ -141,6 +137,7 @@ def metric_registry(metric_type, framework):
         for single_framework in [fwk.strip() for fwk in framework.split(',')]:
             assert single_framework in [
                 "tensorflow",
+                "inteltensorflow",
                 "tensorflow_itex",
                 "mxnet",
                 "onnxrt_qlinearops",
@@ -150,7 +147,7 @@ def metric_registry(metric_type, framework):
                 "pytorch",
                 "pytorch_ipex",
                 "pytorch_fx",
-                "engine"], "The framework support tensorflow mxnet pytorch onnxrt engine"
+                ], "The framework support tensorflow mxnet pytorch onnxrt"
 
             if metric_type in registry_metrics[single_framework].keys():
                 raise ValueError('Cannot have two metrics with the same name')
@@ -306,8 +303,7 @@ def _shape_validate(preds, labels):
             'Shape mismatch, label shape {} vs pred shape {}'.format(label.shape, pred.shape)
     return preds, labels
 
-@metric_registry('F1', 'tensorflow, pytorch, mxnet, onnxrt_qlinearops, \
-                        onnxrt_integerops, engine')
+@metric_registry('F1', 'tensorflow, inteltensorflow, pytorch, mxnet, onnxrt_qlinearops, onnxrt_integerops')
 class F1(BaseMetric):
     """Computes the F1 score of a binary classification problem.
 
@@ -366,8 +362,7 @@ def _accuracy_type_check(preds, labels):
            update_type = 'multilabel'
    return update_type
 
-@metric_registry('Accuracy', 'tensorflow, pytorch, onnxrt_qlinearops, \
-                              onnxrt_integerops, engine')
+@metric_registry('Accuracy', 'tensorflow, inteltensorflow, pytorch, onnxrt_qlinearops, onnxrt_integerops')
 class Accuracy(BaseMetric):
     """Computes accuracy classification score.
 
@@ -447,7 +442,7 @@ class PyTorchLoss():
                                       before it can be computed.")
         return self._sum.item() / self._num_examples
         
-@metric_registry('Loss', 'tensorflow, pytorch, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('Loss', 'tensorflow, inteltensorflow, pytorch, onnxrt_qlinearops, onnxrt_integerops')
 class Loss(BaseMetric):
     """A dummy metric for directly printing loss, it calculates the average of predictions.
 
@@ -475,7 +470,7 @@ class Loss(BaseMetric):
             return allgather_sum / allgather_sample
         return self.sum / self.sample
 
-@metric_registry('MAE', 'tensorflow, pytorch, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('MAE', 'tensorflow, inteltensorflow, pytorch, onnxrt_qlinearops, onnxrt_integerops')
 class MAE(BaseMetric):
     """Computes Mean Absolute Error (MAE) loss.
 
@@ -510,8 +505,7 @@ class MAE(BaseMetric):
             aes_size = sum(self._hvd.allgather_object(aes_size))       
         return aes_sum / aes_size
 
-@metric_registry('RMSE', 'tensorflow, pytorch, mxnet, onnxrt_qlinearops, \
-                          onnxrt_integerops, engine')
+@metric_registry('RMSE', 'tensorflow, inteltensorflow, pytorch, mxnet, onnxrt_qlinearops, onnxrt_integerops')
 class RMSE(BaseMetric):
     """Computes Root Mean Squared Error (RMSE) loss.
 
@@ -536,7 +530,7 @@ class RMSE(BaseMetric):
             self.mse._hvd = self._hvd
         return np.sqrt(self.mse.result())
 
-@metric_registry('MSE', 'tensorflow, pytorch, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('MSE', 'tensorflow, inteltensorflow, pytorch, onnxrt_qlinearops, onnxrt_integerops')
 class MSE(BaseMetric):
     """Computes Mean Squared Error (MSE) loss.
 
@@ -571,7 +565,7 @@ class MSE(BaseMetric):
             squares_size = sum(self._hvd.allgather_object(squares_size))       
         return squares_sum / squares_size
 
-@metric_registry('topk', 'tensorflow')
+@metric_registry('topk', 'tensorflow, inteltensorflow')
 class TensorflowTopK(BaseMetric):
     """Computes top k predictions accuracy.
 
@@ -616,7 +610,7 @@ class TensorflowTopK(BaseMetric):
             return allgather_num_correct / allgather_num_sample 
         return self.num_correct / self.num_sample
 
-@metric_registry('topk', 'pytorch, mxnet, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('topk', 'pytorch, mxnet, onnxrt_qlinearops, onnxrt_integerops')
 class GeneralTopK(BaseMetric):
     """Computes top k predictions accuracy.
 
@@ -662,7 +656,7 @@ class GeneralTopK(BaseMetric):
             return allgather_num_correct / allgather_num_sample
         return self.num_correct / self.num_sample
 
-@metric_registry('COCOmAPv2', 'tensorflow, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('COCOmAPv2', 'tensorflow, inteltensorflow, onnxrt_qlinearops, onnxrt_integerops')
 class COCOmAPv2(BaseMetric):
     """Computes mean average precision.
     Args:
@@ -809,7 +803,7 @@ class COCOmAPv2(BaseMetric):
 
             return box_metrics[self.map_key]
 
-@metric_registry('mAP', 'tensorflow, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('mAP', 'tensorflow, inteltensorflow, onnxrt_qlinearops, onnxrt_integerops')
 class TensorflowMAP(BaseMetric):
     """Computes mean average precision.
 
@@ -957,7 +951,7 @@ class TensorflowMAP(BaseMetric):
 
             return box_metrics[self.map_key]
 
-@metric_registry('COCOmAP', 'tensorflow, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('COCOmAP', 'tensorflow, inteltensorflow, onnxrt_qlinearops, onnxrt_integerops')
 class TensorflowCOCOMAP(TensorflowMAP):
     """Computes mean average precision using algorithm in COCO
 
@@ -973,7 +967,7 @@ class TensorflowCOCOMAP(TensorflowMAP):
         self.iou_thrs = '0.5:0.05:0.95'
         self.map_points = 101
 
-@metric_registry('VOCmAP', 'tensorflow, onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('VOCmAP', 'tensorflow, inteltensorflow, onnxrt_qlinearops, onnxrt_integerops')
 class TensorflowVOCMAP(TensorflowMAP):
     """Computes mean average precision using algorithm in VOC
 
@@ -988,7 +982,7 @@ class TensorflowVOCMAP(TensorflowMAP):
         self.iou_thrs = 0.5
         self.map_points = 0
 
-@metric_registry('SquadF1', 'tensorflow, engine')
+@metric_registry('SquadF1', 'tensorflow, inteltensorflow')
 class SquadF1(BaseMetric):
     """Evaluate for v1.1 of the SQuAD dataset
 
@@ -1024,7 +1018,7 @@ class SquadF1(BaseMetric):
         return np.array(self._score_list).mean()
 
 
-@metric_registry('mIOU', 'tensorflow, engine')
+@metric_registry('mIOU', 'tensorflow, inteltensorflow')
 class mIOU(BaseMetric):
     def __init__(self, num_classes=21):
         self.num_classes = num_classes
@@ -1061,7 +1055,7 @@ class mIOU(BaseMetric):
         mean_iu = np.nanmean(iu)
         return mean_iu
 
-@metric_registry('GLUE', 'onnxrt_qlinearops, onnxrt_integerops, engine')
+@metric_registry('GLUE', 'onnxrt_qlinearops, onnxrt_integerops')
 class ONNXRTGLUE(BaseMetric):
     """Computes GLUE score.
 
@@ -1120,7 +1114,8 @@ class ONNXRTGLUE(BaseMetric):
         result = transformers.glue_compute_metrics(\
             self.task, processed_preds, self.label_list)
         return result[self.return_key[self.task]]
-@metric_registry('ROC', 'pytorch, engine')
+
+@metric_registry('ROC', 'pytorch')
 class ROC(BaseMetric):
     """Computes ROC score.
 
