@@ -20,13 +20,13 @@ import os
 import importlib
 from collections import OrderedDict
 from abc import abstractmethod
-from neural_compressor.utils.utility import LazyImport, compute_sparsity
+from neural_compressor.utils.utility import LazyImport, compute_sparsity, get_backend
+from neural_compressor.utils.utility import version1_lt_version2, version1_gt_version2, version1_gte_version2
 from neural_compressor.utils import logger
 from neural_compressor.conf.dotdict import deep_get, deep_set
 from neural_compressor.conf import config as cfg
 from neural_compressor.model.base_model import BaseModel
 from neural_compressor.model.onnx_model import ONNXModel
-from neural_compressor.model.engine_model import EngineModel
 
 TORCH = False
 if importlib.util.find_spec('torch'):
@@ -66,7 +66,7 @@ def get_model_type(model):
     elif isinstance(model, str):
         model = os.path.abspath(os.path.expanduser(model))
         if (model.endswith('.h5') and os.path.isfile(model)):
-            if tf.version.VERSION < '2.3.0':
+            if version1_lt_version2(tf.version.VERSION, '2.3.0'):
                 logger.warn("keras model running on tensorflow 2.2.0 and"
                             " lower may have problem.")
             model = tf.keras.models.load_model(model)
@@ -77,7 +77,7 @@ def get_model_type(model):
                 # Warning: TF compatibility issue to load saved model. TF 2.3 keras.load
                 # can load saved model from TF backend, but TF 2.4 cannot.
                 try:
-                    if tf.version.VERSION < '2.3.0':
+                    if version1_lt_version2(tf.version.VERSION, '2.3.0'):
                         logger.warn("keras model running on tensorflow 2.2.0 and"
                                     " lower may have problem.")
                     model = tf.keras.models.load_model(model)
@@ -99,7 +99,7 @@ def get_model_type(model):
                 # it's very ugly tf version issue, in tf2.3 keras.load can
                 #batch_size_(batch_size), load saved model from tf backend, but tf2.4 it will crash
                 try:
-                    if tf.version.VERSION < '2.3.0':
+                    if version1_lt_version2(tf.version.VERSION, '2.3.0'):
                         logger.warn("keras model running on tensorflow 2.2.0 and"
                                     " lower may have problem.")
                     model = tf.keras.models.load_model(model)
@@ -174,30 +174,7 @@ def get_model_fwk_name(model):
     if isinstance(model, TensorflowBaseModel):
         return 'tensorflow'
 
-    def _is_engine(model):
-        if model and os.path.isdir(model):
-            file_list = os.listdir(model)
-            is_engine = True
-            if len(file_list) == 2:
-                for file_name in file_list:
-                    file_ext= os.path.splitext(file_name)
-                    front, ext = file_ext
-                    if ext == ".yaml":
-                        is_engine &= True
-                    elif ext == ".bin":
-                        is_engine &= True
-                    else:
-                        is_engine &= False
-                        logger.error("Please Input yaml and bin for engine.")
-                        return 'NA'
-            else:
-                return 'NA'
-            if is_engine == True:
-                return 'engine'
-        else:
-            return 'NA'
-
-    checker = [_is_tensorflow, _is_pytorch, _is_onnxruntime, _is_mxnet, _is_engine]
+    checker = [_is_tensorflow, _is_pytorch, _is_onnxruntime, _is_mxnet]
     for handler in checker:
         fwk_name = handler(model)
         if fwk_name != 'NA':
@@ -271,6 +248,10 @@ def graph_session(model, input_tensor_names, output_tensor_names, **kwargs):
     config = tf.compat.v1.ConfigProto()
     config.use_per_session_threads = 1
     config.inter_op_parallelism_threads = 1
+    if get_backend() == 'tensorflow_itex':
+        from tensorflow.core.protobuf import rewriter_config_pb2
+        config.graph_options.rewrite_options.constant_folding = \
+                  rewriter_config_pb2.RewriterConfig.OFF
     sess = tf.compat.v1.Session(graph=model, config=config)
 
     input_tensor_names, output_tensor_names = validate_and_inference_input_output(\
@@ -345,17 +326,17 @@ def keras_session(model, input_tensor_names, output_tensor_names, **kwargs):
         output_tensor_names (list of string): validated output_tensor_names
     """
 
-    assert tf.version.VERSION >= '2.3.0', 'keras model need tensorflow version >= 2.3.0....'
+    assert version1_gte_version2(tf.version.VERSION, '2.3.0'), 'keras model need tensorflow version >= 2.3.0....'
     from tensorflow.python.framework.convert_to_constants import convert_variables_to_constants_v2
     if not isinstance(model, tf.keras.Model):
         model = tf.keras.models.load_model(model)
     kwargs = dict(zip(model.input_names, model.inputs))
-    if tf.version.VERSION > '2.2.0' and tf.version.VERSION < '2.5.0':
+    if version1_gt_version2(tf.version.VERSION, '2.2.0') and version1_lt_version2(tf.version.VERSION, '2.5.0'):
         from tensorflow.python.keras.engine import keras_tensor
         if keras_tensor.keras_tensors_enabled():
             for name, tensor in kwargs.items():
                 kwargs[name] = tensor.type_spec
-    elif tf.version.VERSION >= '2.5.0':
+    elif version1_gte_version2(tf.version.VERSION, '2.5.0'):
         for name, tensor in kwargs.items():
             kwargs[name] = tensor.type_spec
     full_model = tf.function(lambda **kwargs: model(kwargs.values(), training=False))
@@ -408,7 +389,7 @@ def slim_session(model, input_tensor_names, output_tensor_names, **kwargs):
         output_tensor_names (list of string): validated output_tensor_names
     """
 
-    assert tf.version.VERSION < '2.0.0', 'slim model only used in tensorflow 1.x'
+    assert version1_lt_version2(tf.version.VERSION, '2.0.0'), 'slim model only used in tensorflow 1.x'
     from .nets_factory import TFSlimNetsFactory
     factory = TFSlimNetsFactory()
     assert 'name' in kwargs, 'model name should be set in slim checkpoint....'
@@ -467,6 +448,10 @@ def checkpoint_session(model, input_tensor_names, output_tensor_names, **kwargs)
     config = tf.compat.v1.ConfigProto()
     config.use_per_session_threads = 1
     config.inter_op_parallelism_threads = 1
+    if get_backend() == 'tensorflow_itex':
+        from tensorflow.core.protobuf import rewriter_config_pb2
+        config.graph_options.rewrite_options.constant_folding = \
+                 rewriter_config_pb2.RewriterConfig.OFF
     graph = tf.Graph()
     sess = tf.compat.v1.Session(graph=graph, config=config)
     with graph.as_default():
@@ -545,6 +530,10 @@ def saved_model_session(model, input_tensor_names, output_tensor_names, **kwargs
     config = tf.compat.v1.ConfigProto()
     config.use_per_session_threads = 1
     config.inter_op_parallelism_threads = 1
+    if get_backend() == 'tensorflow_itex':
+        from tensorflow.core.protobuf import rewriter_config_pb2
+        config.graph_options.rewrite_options.constant_folding = \
+                    rewriter_config_pb2.RewriterConfig.OFF
     if not os.listdir(os.path.join(model,'variables')):
         sess = tf.compat.v1.Session(graph=tf.Graph(), config=config)
         loader = tf.compat.v1.saved_model.loader.load(sess, ["serve"], model)
@@ -994,22 +983,37 @@ class MXNetModel(BaseModel):
         os.makedirs(os.path.dirname(root), exist_ok=True)
 
         if isinstance(self._model, mx.gluon.HybridBlock):
-            self._model.export(root)
+            self._model.export(root, remove_amp_cast=False)
             logger.info("Save quantized hybrid block model to {}.".format(root))
         else:
             symnet, args, auxs = self._model
             symnet = symnet.as_nd_ndarray()
             args = {k:v.as_nd_ndarray() for k, v in args.items()}
             auxs = {k:v.as_nd_ndarray() for k, v in auxs.items()}
-            mx.model.save_checkpoint(root, 0, symnet, args, auxs)
+            mx.model.save_checkpoint(root, 0, symnet, args, auxs, remove_amp_cast=False)
             logger.info("Save quantized symbol model to {}.".format(root))
 
 
 MODELS = {'tensorflow': TensorflowModel,
+          'inteltensorflow': TensorflowModel,
           'tensorflow_itex': TensorflowModel,
           'mxnet': MXNetModel,
           'pytorch': PyTorchModel if TORCH else None,
           'pytorch_ipex': PyTorchIpexModel if TORCH else None,
           'pytorch_fx': PyTorchFXModel if TORCH else None,
           'onnxruntime': ONNXModel,
-          'engine': EngineModel}
+          }
+
+
+def export(model: BaseModel, path: str, to_onnx: bool = False):
+    """_summary_
+
+    Args:
+        model (BaseModel): optimized model
+        path (str): path to save model
+        to_onnx (bool, optional): whether to convert to onnx model. Defaults to False.
+    """
+    if to_onnx:
+        assert False, "Not support yet!"
+    else:
+        model.save(path)
