@@ -24,6 +24,7 @@ class onnxrt:
                            'DedicatedQDQPair': False})
 
 OPTIONS = {'tensorflow': None,
+           'inteltensorflow': None,
            'tensorflow_itex': None,
            'pytorch': None,
            'pytorch_fx': None,
@@ -33,6 +34,6 @@ OPTIONS = {'tensorflow': None,
            'onnxrt_qlinearops': onnxrt,
            'onnxrt_qdq': onnxrt,
            'onnxrt_qoperator': onnxrt,
-           'engine': None}
+           }
 
 
