@@ -19,6 +19,7 @@ from ..adaptor.pytorch import _cfg_to_qconfig, _cfgs_to_fx_cfgs
 from ..adaptor.pytorch import _propagate_qconfig, get_torch_version
 from ..adaptor.pytorch import PyTorchVersionMode
 from ..adaptor.pytorch import PyTorch_FXAdaptor
+from ..adaptor.torch_utils.util import get_embedding_contiguous
 from . import logger
 import torch
 from torch.quantization import add_observer_, convert
@@ -54,6 +55,7 @@ def _set_sub_module_scale_zeropoint(model, tune_cfg, prefix=''):
         else:
             _set_sub_module_scale_zeropoint(module, tune_cfg, op_name)
 
+
 def _set_activation_scale_zeropoint(q_model, tune_cfg):
     """set activation scale and zero_point for converted model.
 
@@ -92,6 +94,45 @@ def _set_activation_scale_zeropoint(q_model, tune_cfg):
         else:
             _set_sub_module_scale_zeropoint(q_model, tune_cfg)
 
+
+def _load_int8_orchestration(model, tune_cfg, stat_dict, **kwargs):
+    q_cfgs = torch.quantization.QConfig(
+                activation=torch.quantization.FakeQuantize.with_args(
+                        dtype=torch.quint8,
+                        qscheme=torch.per_tensor_affine,
+                        reduce_range=tune_cfg['reduce_range']),
+                weight=torch.quantization.default_weight_fake_quant)
+    if tune_cfg['framework'] == 'pytorch_fx':
+        from torch.quantization.quantize_fx import prepare_qat_fx, convert_fx
+        quantized_ops = {op[0]: q_cfgs for op in tune_cfg['quantizable_ops']}
+        version = get_torch_version()
+        if version < PyTorchVersionMode.PT111.value:
+            quantized_ops["default_qconfig"] = None
+        fx_op_cfgs = _cfgs_to_fx_cfgs(quantized_ops, 'quant_aware_training')
+        model.train()
+        if tune_cfg['sub_module_list'] is None:
+            model = prepare_qat_fx(model, fx_op_cfgs,
+               prepare_custom_config_dict=kwargs.get('prepare_custom_config_dict', None)
+               if kwargs is not None else None)
+            model = convert_fx(model,
+              convert_custom_config_dict=kwargs.get('convert_custom_config_dict', None)
+                if kwargs is not None else None)
+        else:
+            logger.info('Fx trace of the entire model failed. ' + \
+                        'We will conduct auto quantization')
+            PyTorch_FXAdaptor.prepare_sub_graph(tune_cfg['sub_module_list'], fx_op_cfgs, \
+                                                model, prefix='', is_qat=True)
+            PyTorch_FXAdaptor.convert_sub_graph(tune_cfg['sub_module_list'], \
+                                                model, prefix='')
+    else:
+        model.training = True
+        model.qconfig = q_cfgs
+        torch.quantization.prepare_qat(model, inplace=True)
+        torch.quantization.convert(model, inplace=True)
+    model.load_state_dict(stat_dict)
+    return model
+
+
 def load(checkpoint_dir=None, model=None, history_cfg=None, **kwargs):
     """Execute the quantize process on the specified model.
 
@@ -121,13 +162,25 @@ def load(checkpoint_dir=None, model=None, history_cfg=None, **kwargs):
             logger.error("Unexpected checkpoint type:{}. \
               Only file dir/path or state_dict is acceptable")
         assert 'best_configure' in stat_dict, \
-          "No best_configure found in model file, please use the model file generated by INC"
+          "No best_configure found in the model file, " \
+          "please use the int8 model file generated by INC"
         tune_cfg = stat_dict.pop('best_configure')
     else:
         assert history_cfg is not None, \
           "Need chieckpoint_dir or history_cfg to rebuild int8 model"
         tune_cfg = history_cfg
 
+    try:
+        q_model = copy.deepcopy(model)
+    except Exception as e:                                           # pragma: no cover
+        logger.warning("Fail to deep copy the model due to {}, inplace is used now.".
+                       format(repr(e)))
+        q_model = model
+
+    if 'is_oneshot' in tune_cfg and tune_cfg['is_oneshot']:
+        return _load_int8_orchestration(q_model, tune_cfg, stat_dict, **kwargs)
+
+    q_model.eval()
     version = get_torch_version()
     if tune_cfg['approach'] != "post_training_dynamic_quant":
         if version < PyTorchVersionMode.PT17.value:   # pragma: no cover
@@ -149,14 +202,6 @@ def load(checkpoint_dir=None, model=None, history_cfg=None, **kwargs):
             q_mapping = \
                 tq.quantization_mappings.get_default_dynamic_quant_module_mappings()
 
-    model.eval()
-    try:
-        q_model = copy.deepcopy(model)
-    except Exception as e:                                           # pragma: no cover
-        logger.warning("Fail to deep copy the model due to {}, inplace is used now.".
-                       format(repr(e)))
-        q_model = model
-
     if tune_cfg['framework'] == "pytorch_fx":             # pragma: no cover
         # For torch.fx approach
         assert version >= PyTorchVersionMode.PT18.value, \
@@ -194,31 +239,22 @@ def load(checkpoint_dir=None, model=None, history_cfg=None, **kwargs):
                                                     prefix='')
             PyTorch_FXAdaptor.convert_sub_graph(sub_module_list, \
                                                 q_model, prefix='')
-
-        bf16_ops_list = tune_cfg['bf16_ops_list'] if 'bf16_ops_list' in tune_cfg.keys() else []
-        if len(bf16_ops_list) > 0 and (version >= PyTorchVersionMode.PT111.value):
-            from ..adaptor.torch_utils.bf16_convert import Convert
-            q_model = Convert(q_model, tune_cfg)
-        if checkpoint_dir is None and history_cfg is not None:
-            _set_activation_scale_zeropoint(q_model, history_cfg)
-        else:
-            q_model.load_state_dict(stat_dict)
-        return q_model
-
-    if tune_cfg['approach'] == "post_training_dynamic_quant":
-        op_cfgs = _cfg_to_qconfig(tune_cfg, tune_cfg['approach'])
     else:
-        op_cfgs = _cfg_to_qconfig(tune_cfg)
+        if tune_cfg['approach'] == "post_training_dynamic_quant":
+            op_cfgs = _cfg_to_qconfig(tune_cfg, tune_cfg['approach'])
+        else:
+            op_cfgs = _cfg_to_qconfig(tune_cfg)
+
+        _propagate_qconfig(q_model, op_cfgs, approach=tune_cfg['approach'])
+        # sanity check common API misusage
+        if not any(hasattr(m, 'qconfig') and m.qconfig for m in q_model.modules()):
+            logger.warn("None of the submodule got qconfig applied. Make sure you "
+                        "passed correct configuration through `qconfig_dict` or "
+                        "by assigning the `.qconfig` attribute directly on submodules")
+        if tune_cfg['approach'] != "post_training_dynamic_quant":
+            add_observer_(q_model)
+        q_model = convert(q_model, mapping=q_mapping, inplace=True)
 
-    _propagate_qconfig(q_model, op_cfgs, approach=tune_cfg['approach'])
-    # sanity check common API misusage
-    if not any(hasattr(m, 'qconfig') and m.qconfig for m in q_model.modules()):
-        logger.warn("None of the submodule got qconfig applied. Make sure you "
-                    "passed correct configuration through `qconfig_dict` or "
-                    "by assigning the `.qconfig` attribute directly on submodules")
-    if tune_cfg['approach'] != "post_training_dynamic_quant":
-        add_observer_(q_model)
-    q_model = convert(q_model, mapping=q_mapping, inplace=True)
     bf16_ops_list = tune_cfg['bf16_ops_list'] if 'bf16_ops_list' in tune_cfg.keys() else []
     if len(bf16_ops_list) > 0 and (version >= PyTorchVersionMode.PT111.value):
         from ..adaptor.torch_utils.bf16_convert import Convert
@@ -227,4 +263,5 @@ def load(checkpoint_dir=None, model=None, history_cfg=None, **kwargs):
         _set_activation_scale_zeropoint(q_model, history_cfg)
     else:
         q_model.load_state_dict(stat_dict)
+    get_embedding_contiguous(q_model)
     return q_model
