@@ -29,6 +29,7 @@ import time
 import sys
 import pickle
 import logging
+import importlib
 from contextlib import contextmanager
 from tempfile import NamedTemporaryFile
 import os.path as osp
@@ -40,6 +41,52 @@ import prettytable as pt
 import psutil
 import subprocess
 from enum import Enum
+from pkg_resources import parse_version
+
+def version1_lt_version2(version1, version2):
+    return parse_version(version1) < parse_version(version2)
+    
+def version1_gt_version2(version1, version2):
+    return parse_version(version1) > parse_version(version2)
+
+def version1_eq_version2(version1, version2):
+    return parse_version(version1) == parse_version(version2)
+
+def version1_gte_version2(version1, version2):
+    return parse_version(version1) > parse_version(version2) or parse_version(version1) == parse_version(version2)
+
+def version1_lte_version2(version1, version2):
+    return parse_version(version1) < parse_version(version2) or parse_version(version1) == parse_version(version2)
+
+
+class LazyImport(object):
+    """Lazy import python module till use
+
+       Args:
+           module_name (string): The name of module imported later
+    """
+
+    def __init__(self, module_name):
+        self.module_name = module_name
+        self.module = None
+
+    def __getattr__(self, name):
+        try:
+            self.module = importlib.import_module(self.module_name)
+            mod = getattr(self.module, name)
+        except:
+            spec = importlib.util.find_spec(str(self.module_name + '.' + name))
+            mod = importlib.util.module_from_spec(spec)
+            spec.loader.exec_module(mod)
+        return mod
+
+    def __call__(self, *args, **kwargs):
+        function_name = self.module_name.split('.')[-1]
+        module_name = self.module_name.split(f'.{function_name}')[0]
+        self.module = importlib.import_module(module_name)
+        function = getattr(self.module, function_name)
+        return function(*args, **kwargs)
+
 
 def singleton(cls):
     instances = {}
@@ -58,33 +105,6 @@ def get_backend():
     global __BACKEND
     return __BACKEND
 
-class LazyImport(object):
-    """Lazy import python module till use
-
-       Args:
-           module_name (string): The name of module imported later
-    """
-
-    def __init__(self, module_name):
-        self.module_name = module_name
-        self.module = None
-
-    def __getattr__(self, name):
-        if self.module is None:
-            # __import__ returns top level module
-            top_level_module = __import__(self.module_name)
-            if len(self.module_name.split('.')) == 1:
-                self.module = top_level_module
-            else:
-                # for cases that input name is foo.bar.module
-                module_list = self.module_name.split('.')
-                temp_module = top_level_module
-                for temp_name in module_list[1:]:
-                    temp_module = getattr(temp_module, temp_name)
-                self.module = temp_module
-
-        return getattr(self.module, name)
-
 @contextmanager
 def time_limit(seconds):
     if seconds == 0:
@@ -344,29 +364,22 @@ def str2array(s):
 
 def DequantizeWeight(weight_tensor, min_filter_tensor, max_filter_tensor):
     weight_channel = weight_tensor.shape[-1]
-
+    if len(min_filter_tensor) == 1:
+        return weight_tensor * ((max_filter_tensor[0] - min_filter_tensor[0])/ 127.0)
+    # TODO to calculate the de-quantized result in a parallel way
     for i in range(weight_channel):
-        data = weight_tensor[:,:,:,i]
-        new_data = data.reshape(data.size,)
-        if len(min_filter_tensor) == weight_channel:
-            # per_channel mode
-            for j in range((data.size)):
-                new_data[j] = \
-                        float(new_data[j] *(max_filter_tensor[i] - min_filter_tensor[i])/ 127.0)
-        else:
-            # per_tensor mode
-            for j in range((data.size)):
-                new_data[j] = \
-                        float(new_data[j] *(max_filter_tensor[0] - min_filter_tensor[0])/ 127.0)
+        weight_tensor[:,:,:,i] = weight_tensor[:,:,:,i] * ((max_filter_tensor[i] - min_filter_tensor[i])/ 127.0)
+
 
 
 def Dequantize(data, scale_info):
+    import numpy as np
     original_shape = data.shape
-    size = data.size
-    new_data = data.reshape(size, )
-    max_value = 255 if scale_info[0].find("Relu") != -1 else 127
-    return np.array([float(i *(scale_info[2] - scale_info[1])/ max_value) for i in new_data]\
-            ).reshape(original_shape)
+    max_value = 255.0 if scale_info[0].find("Relu") != -1.0 else 127.0
+    _scale = (np.array(scale_info[2]) - np.array(scale_info[1])) / max_value
+    de_scale = np.ones(original_shape) * _scale
+    de_data = np.multiply(data, de_scale).astype(np.float32)
+    return de_data
 
 
 class CaptureOutputToFile(object):
@@ -424,3 +437,42 @@ class MODE(Enum):
 
 class GLOBAL_STATE():
     STATE = MODE.QUANTIZATION
+
+def load_data_from_pkl(path, filename):
+    """
+    load data from local pkl file
+    Args:
+        path: the directory to load data
+        filename: filename to load
+
+    Returns:
+        None
+
+    """
+    try:
+        file_path = os.path.join(path, filename)
+        with open(file_path, 'rb') as fp:
+            data = pickle.load(fp)
+            return data
+    except FileExistsError:
+        logging.getLogger().info('Can not open %s.' % path)
+
+def dump_data_to_local(data, path, filename):
+    """
+    Dump data to local as pkl file
+    Args:
+        data: data used to dump
+        path: the directory to save data
+        filename: filename to dump
+
+    Returns:
+        loaded data
+
+    """
+    from pathlib import Path
+    if not os.path.exists(path):
+        Path(path).mkdir(parents=True, exist_ok=True)
+    file_path = os.path.join(path, filename)
+    with open(file_path, 'wb') as fp:
+        pickle.dump(data, fp)
+        logging.getLogger().info("Dumped data to %s" % file_path)
